@@ -18,16 +18,23 @@ from .recaptchaenterprise import (
     AnnotateAssessmentRequest,
     AnnotateAssessmentResponse,
     Assessment,
+    ChallengeMetrics,
     CreateAssessmentRequest,
     CreateKeyRequest,
     DeleteKeyRequest,
     Event,
     GetKeyRequest,
+    GetMetricsRequest,
     IOSKeySettings,
     Key,
     ListKeysRequest,
     ListKeysResponse,
+    Metrics,
+    MigrateKeyRequest,
     RiskAnalysis,
+    ScoreDistribution,
+    ScoreMetrics,
+    TestingOptions,
     TokenProperties,
     UpdateKeyRequest,
     WebKeySettings,
@@ -38,16 +45,23 @@ __all__ = (
     "AnnotateAssessmentRequest",
     "AnnotateAssessmentResponse",
     "Assessment",
+    "ChallengeMetrics",
     "CreateAssessmentRequest",
     "CreateKeyRequest",
     "DeleteKeyRequest",
     "Event",
     "GetKeyRequest",
+    "GetMetricsRequest",
     "IOSKeySettings",
     "Key",
     "ListKeysRequest",
     "ListKeysResponse",
+    "Metrics",
+    "MigrateKeyRequest",
     "RiskAnalysis",
+    "ScoreDistribution",
+    "ScoreMetrics",
+    "TestingOptions",
     "TokenProperties",
     "UpdateKeyRequest",
     "WebKeySettings",
